@@ -56,6 +56,9 @@ INTERNALERROR_UNDEFIENDERROR = 'InternalError.UndefiendError'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 已经存在绑定的账号。
+INVALIDPARAMETER_ACCOUNTEXIST = 'InvalidParameter.AccountExist'
+
 # 非法CIDR。
 INVALIDPARAMETER_ILLEGALCIDR = 'InvalidParameter.IllegalCidr'
 
@@ -119,6 +122,9 @@ INVALIDPARAMETER_RECORDUNSUPPORTWEIGHT = 'InvalidParameter.RecordUnsupportWeight
 # VPC已绑定其它解析域。
 INVALIDPARAMETER_VPCBINDED = 'InvalidParameter.VpcBinded'
 
+# 当前VPC已关联相同主域名。
+INVALIDPARAMETER_VPCBINDEDMAINDOMAIN = 'InvalidParameter.VpcBindedMainDomain'
+
 # VPC关联反解析域超过限制。
 INVALIDPARAMETER_VPCPTRZONEBINDEXCEED = 'InvalidParameter.VpcPtrZoneBindExceed'
 
@@ -128,9 +134,18 @@ INVALIDPARAMETER_ZONENOTEXISTS = 'InvalidParameter.ZoneNotExists'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 内部专用TLD，不支持创建。
+INVALIDPARAMETERVALUE_RESERVEDDOMAIN = 'InvalidParameterValue.ReservedDomain'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 超过自定义TLD额度。
+LIMITEXCEEDED_TLDOUTOFLIMIT = 'LimitExceeded.TldOutOfLimit'
+
+# 使用自定义TLD的私有域超过总额度。
+LIMITEXCEEDED_TLDOUTOFRANGE = 'LimitExceeded.TldOutOfRange'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -155,6 +170,12 @@ RESOURCENOTFOUND_SERVICENOTSUBSCRIBED = 'ResourceNotFound.ServiceNotSubscribed'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# TLD增值包超额不允许操作。
+RESOURCEUNAVAILABLE_TLDOPERATELIMIT = 'ResourceUnavailable.TldOperateLimit'
+
+# TLD增值包已过期。
+RESOURCEUNAVAILABLE_TLDPACKAGEEXPIRED = 'ResourceUnavailable.TldPackageExpired'
+
 # 资源售罄。
 RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
@@ -175,3 +196,9 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
 # 账号未绑定。
 UNSUPPORTEDOPERATION_ACCOUNTNOTBOUND = 'UnsupportedOperation.AccountNotBound'
+
+# 存在绑定的VPC资源。
+UNSUPPORTEDOPERATION_EXISTBOUNDVPC = 'UnsupportedOperation.ExistBoundVpc'
+
+# 接口调用超过限频。
+UNSUPPORTEDOPERATION_FREQUENCYLIMIT = 'UnsupportedOperation.FrequencyLimit'
